==> nmrium-0.50.1.tgz: package/lib/component/panels/Panels.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import lodashGet from 'lodash/get';
import { useCallback, memo } from 'react';
import { Accordion } from 'react-science/ui';
import { useChartData } from '../context/ChartContext';
import { usePreferences } from '../context/PreferencesContext';
import useCheckExperimentalFeature from '../hooks/useCheckExperimentalFeature';
import AutomaticAssignment from './AutomaticAssignment/AutomaticAssignment';
import InformationPanel from './InformationPanel';
import IntegralPanel from './IntegralsPanel/IntegralPanel';
import MatrixGenerationPanel from './MatrixGenerationPanel/MatrixGenerationPanel';
import MoleculePanel from './MoleculesPanel/MoleculePanel';
import PeaksPanel from './PeaksPanel/PeaksPanel';
import RangesPanel from './RangesPanel/RangesPanel';
import SpectrumListPanel from './SpectrumsPanel/SpectrumListPanel';
import SummaryPanel from './SummaryPanel/SummaryPanel';
import ZonesPanel from './ZonesPanel/ZonesPanel';
import DatabasePanel from './databasePanel/DatabasePanel';
import FilterPanel from './filtersPanel/FilterPanel';
import MultipleSpectraAnalysisPanel from './multipleAnalysisPanel/MultipleSpectraAnalysisPanel';
import PredictionPane from './predictionPanel/PredictionPanel';
import SpectrumSimulation from './spectrumSimulation/SpectrumSimulation';
const accordionItems = [
    {
        title: 'Spectra',
        component: _jsx(SpectrumListPanel, {}),
        hidePreferenceKey: 'spectraPanel',
        mode: null,
    },
    {
        title: 'Information',
        component: _jsx(InformationPanel, {}),
        style: { overflow: 'hidden' },
        hidePreferenceKey: 'informationPanel',
        mode: null,
    },
    {
        title: 'Peaks',
        component: _jsx(PeaksPanel, {}),
        hidePreferenceKey: 'peaksPanel',
        mode: '1D',
    },
    {
        title: 'Processings',
        component: _jsx(FilterPanel, {}),
        hidePreferenceKey: 'processingsPanel',
        mode: null,
    },
    {
        title: 'Integrals',
        component: _jsx(IntegralPanel, {}),
        hidePreferenceKey: 'integralsPanel',
        mode: '1D',
    },
    {
        title: 'Ranges',
        component: _jsx(RangesPanel, {}),
        hidePreferenceKey: 'rangesPanel',
        mode: '1D',
    },
    {
        title: 'Multiple Spectra Analysis',
        component: _jsx(MultipleSpectraAnalysisPanel, {}),
        hidePreferenceKey: 'multipleSpectraAnalysisPanel',
        mode: null,
    },
    {
        title: 'Matrix Generation',
        component: _jsx(MatrixGenerationPanel, {}),
        hidePreferenceKey: 'matrixGenerationPanel',
        mode: '1D',
    },
    {
        title: 'Zones',
        component: _jsx(ZonesPanel, {}),
        hidePreferenceKey: 'zonesPanel',
        mode: '2D',
    },
    {
        title: 'Summary',
        component: _jsx(SummaryPanel, {}),
        hidePreferenceKey: 'summaryPanel',
        mode: null,
    },
    {
        title: 'Chemical structures',
        component: _jsx(MoleculePanel, {}),
        hidePreferenceKey: 'structuresPanel',
        mode: null,
    },
    {
        title: 'Databases',
        component: _jsx(DatabasePanel, {}),
        hidePreferenceKey: 'databasePanel',
        mode: null,
    },
    {
        title: 'Automatic Assignment',
        component: _jsx(AutomaticAssignment, {}),
        hidePreferenceKey: 'automaticAssignmentPanel',
        mode: null,
    },
    {
        title: 'Prediction',
        component: _jsx(PredictionPane, {}),
        hidePreferenceKey: 'predictionPanel',
        mode: null,
    },
    {
        title: 'Spectrum Simulation',
        component: _jsx(SpectrumSimulation, {}),
        hidePreferenceKey: 'simulationPanel',
        mode: '1D',
    },
];
export const TOOLS_PANELS_ACCORDION = {
    null: 'Spectra',
    peakPicking: 'Peaks',
    integral: 'Integrals',
    rangePicking: 'Ranges',
    zonePicking: 'Zones',
    multipleSpectraAnalysis: 'Multiple Spectra Analysis',
};
function usePanelPreferences() {
    const preferences = usePreferences();
    return useCallback((item) => {
        const defaultValue = {
            display: false,
            open: false,
        };
        if (item?.isExperimental && !item.hidePreferenceKey) {
            return {
                display: true,
                open: false,
            };
        }
        return lodashGet(preferences.current, `display.panels.${item.hidePreferenceKey}`, defaultValue);
    }, [preferences]);
}
function PanelsInner({ displayerMode: displayedMode }) {
    const getPanelPreferences = usePanelPreferences();
    const isExperimental = useCheckExperimentalFeature();
    const check = useCallback((item) => {
        const panelOptions = getPanelPreferences(item);
        return ((panelOptions?.display &&
            item.isExperimental === undefined &&
            (item.mode == null || item.mode === displayedMode)) ||
            (item.isExperimental && isExperimental));
    }, [displayedMode, getPanelPreferences, isExperimental]);
    const isOpened = useCallback((item) => {
        const panelOptions = getPanelPreferences(item);
        return panelOptions?.display && panelOptions?.open;
    }, [getPanelPreferences]);
    return (_jsx("div", { style: { width: '100%', height: '100%', flex: '1 1 0%' }, children: _jsx(Accordion, { children: accordionItems.map((item) => {
                return (check(item) && (_jsx(Accordion.Item, { title: item.title, defaultOpened: isOpened(item), children: item.component }, item.title)));
            }) }) }));
}
const MemoizedPanels = memo(PanelsInner);
export default function Panels() {
    const { displayerMode, toolOptions: { selectedTool }, } = useChartData();
    return _jsx(MemoizedPanels, { displayerMode, selectedTool });
}

==> nmrium-0.53.0.tgz: package/lib/component/panels/Panels.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import lodashGet from 'lodash/get';
import { useCallback, memo } from 'react';
import { Accordion } from 'react-science/ui';
import { useChartData } from '../context/ChartContext';
import { usePreferences } from '../context/PreferencesContext';
import useCheckExperimentalFeature from '../hooks/useCheckExperimentalFeature';
import AutomaticAssignment from './AutomaticAssignment/AutomaticAssignment';
import InformationPanel from './InformationPanel';
import IntegralPanel from './IntegralsPanel/IntegralPanel';
import MatrixGenerationPanel from './MatrixGenerationPanel/MatrixGenerationPanel';
import MoleculePanel from './MoleculesPanel/MoleculePanel';
import PeaksPanel from './PeaksPanel/PeaksPanel';
import RangesPanel from './RangesPanel/RangesPanel';
import SpectrumListPanel from './SpectraPanel/SpectrumListPanel';
import SummaryPanel from './SummaryPanel/SummaryPanel';
import ZonesPanel from './ZonesPanel/ZonesPanel';
import DatabasePanel from './databasePanel/DatabasePanel';
import FilterPanel from './filtersPanel/FilterPanel';
import MultipleSpectraAnalysisPanel from './multipleAnalysisPanel/MultipleSpectraAnalysisPanel';
import PredictionPane from './predictionPanel/PredictionPanel';
import SpectrumSimulation from './spectrumSimulation/SpectrumSimulation';
const accordionItems = [
    {
        title: 'Spectra',
        component: _jsx(SpectrumListPanel, {}),
        hidePreferenceKey: 'spectraPanel',
        mode: null,
    },
    {
        title: 'Information',
        component: _jsx(InformationPanel, {}),
        style: { overflow: 'hidden' },
        hidePreferenceKey: 'informationPanel',
        mode: null,
    },
    {
        title: 'Peaks',
        component: _jsx(PeaksPanel, {}),
        hidePreferenceKey: 'peaksPanel',
        mode: '1D',
    },
    {
        title: 'Processings',
        component: _jsx(FilterPanel, {}),
        hidePreferenceKey: 'processingsPanel',
        mode: null,
    },
    {
        title: 'Integrals',
        component: _jsx(IntegralPanel, {}),
        hidePreferenceKey: 'integralsPanel',
        mode: '1D',
    },
    {
        title: 'Ranges',
        component: _jsx(RangesPanel, {}),
        hidePreferenceKey: 'rangesPanel',
        mode: '1D',
    },
    {
        title: 'Multiple spectra analysis',
        component: _jsx(MultipleSpectraAnalysisPanel, {}),
        hidePreferenceKey: 'multipleSpectraAnalysisPanel',
        mode: null,
    },
    {
        title: 'Matrix generation',
        component: _jsx(MatrixGenerationPanel, {}),
        hidePreferenceKey: 'matrixGenerationPanel',
        mode: '1D',
    },
    {
        title: 'Zones',
        component: _jsx(ZonesPanel, {}),
        hidePreferenceKey: 'zonesPanel',
        mode: '2D',
    },
    {
        title: 'Summary',
        component: _jsx(SummaryPanel, {}),
        hidePreferenceKey: 'summaryPanel',
        mode: null,
    },
    {
        title: 'Chemical structures',
        component: _jsx(MoleculePanel, {}),
        hidePreferenceKey: 'structuresPanel',
        mode: null,
    },
    {
        title: 'Databases',
        component: _jsx(DatabasePanel, {}),
        hidePreferenceKey: 'databasePanel',
        mode: null,
    },
    {
        title: 'Automatic assignment',
        component: _jsx(AutomaticAssignment, {}),
        hidePreferenceKey: 'automaticAssignmentPanel',
        mode: null,
    },
    {
        title: 'Prediction',
        component: _jsx(PredictionPane, {}),
        hidePreferenceKey: 'predictionPanel',
        mode: null,
    },
    {
        title: 'Spectrum simulation',
        component: _jsx(SpectrumSimulation, {}),
        hidePreferenceKey: 'simulationPanel',
        mode: '1D',
    },
];
export const TOOLS_PANELS_ACCORDION = {
    null: 'Spectra',
    peakPicking: 'Peaks',
    integral: 'Integrals',
    rangePicking: 'Ranges',
    zonePicking: 'Zones',
    multipleSpectraAnalysis: 'Multiple Spectra Analysis',
};
function usePanelPreferences() {
    const preferences = usePreferences();
    return useCallback((item) => {
        const defaultValue = {
            display: false,
            open: false,
        };
        if (item?.isExperimental && !item.hidePreferenceKey) {
            return {
                display: true,
                open: false,
            };
        }
        return lodashGet(preferences.current, `display.panels.${item.hidePreferenceKey}`, defaultValue);
    }, [preferences]);
}
function PanelsInner({ displayerMode: displayedMode }) {
    const getPanelPreferences = usePanelPreferences();
    const isExperimental = useCheckExperimentalFeature();
    const check = useCallback((item) => {
        const panelOptions = getPanelPreferences(item);
        return ((panelOptions?.display &&
            item.isExperimental === undefined &&
            (item.mode == null || item.mode === displayedMode)) ||
            (item.isExperimental && isExperimental));
    }, [displayedMode, getPanelPreferences, isExperimental]);
    const isOpened = useCallback((item) => {
        const panelOptions = getPanelPreferences(item);
        return panelOptions?.display && panelOptions?.open;
    }, [getPanelPreferences]);
    return (_jsx("div", { style: { width: '100%', height: '100%', flex: '1 1 0%' }, children: _jsx(Accordion, { children: accordionItems.map((item) => {
                return (check(item) && (_jsx(Accordion.Item, { title: item.title, defaultOpened: isOpened(item), children: item.component }, item.title)));
            }) }) }));
}
const MemoizedPanels = memo(PanelsInner);
export default function Panels() {
    const { displayerMode, toolOptions: { selectedTool }, } = useChartData();
    return _jsx(MemoizedPanels, { displayerMode, selectedTool });
}
